==> haskell-kan-extensions-5.2.7-79.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.7
visibility:           public
id:                   kan-extensions-5.2.7-EnBT78A8Pv5AQm9RtrTyNw
key:                  kan-extensions-5.2.7-EnBT78A8Pv5AQm9RtrTyNw
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  76849c980419a0152b6f392c7c978e84
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.7-EnBT78A8Pv5AQm9RtrTyNw
depends:
    adjunctions-4.4.3-JFB4iJ93aO845aovoP0TqZ array-0.5.6.0
    base-4.18.2.1 comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
    free-5.2-3fckYVSYEwRA3sQVkSQiQV
    invariant-0.6.4-DQVW85wmN9o2zzRL81vdJd mtl-2.3.1
    profunctors-5.6.3-1wSzWoPhCYk2rkrLUGeSHx
    semigroupoids-6.0.1-ErxGHkCkp7JG4CGTcMGRW9
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.2.7-80-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 kan-extensions
version:              5.2.7
visibility:           public
id:                   kan-extensions-5.2.7-CxNd8hhXH2ZC3bz6YYdu9A
key:                  kan-extensions-5.2.7-CxNd8hhXH2ZC3bz6YYdu9A
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/kan-extensions/
synopsis:
    Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads

description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.

category:             Data Structures, Monads, Comonads, Functors
abi:                  7a0615c48ebdaf097335991ec794af84
exposed:              True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda

import-dirs:          /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/kan-extensions-5.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-kan-extensions
hs-libraries:         HSkan-extensions-5.2.7-CxNd8hhXH2ZC3bz6YYdu9A
depends:
    adjunctions-4.4.3-CGfiZ0Nwp52HytI706XQqX array-0.5.6.0
    base-4.18.2.1 comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL containers-0.6.7
    contravariant-1.5.5-JUOgBPNZkO18h7ix7HMuaW
    distributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ
    free-5.2-CP2SAI6deNWCXG1eD5QmMc
    invariant-0.6.4-HfDfTohAQvFGFCMlyLEpl3 mtl-2.3.1
    profunctors-5.6.3-11ZlnmbI5xE8sDrL55YXrn
    semigroupoids-6.0.1-133SNw0FNd08WQLIYIjtGS
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock

haddock-html:         /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
